@@ -2,8 +2,8 @@
 Verna: A simple module to handle RGBA colors
 """
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
-from .verna import Color
+from verna.verna import Color
 
 __all__ = ['Color']
